harness_py_sdk.harness_connectors API documentation

# harness_py_sdk.harness_connectors

class HarnessConnectors:
HarnessConnectors(harness_service)
old
def fetch_connector(self, identifier, org_identifier=None, project_identifier=None):

Retrieves the information of the connector with the matching connector identifier. Args: identifier (str): Connector identifier org_identifier (str): Organization identifier project_identifier (str): Project identifier

def fetch_connectors(self, org_identifier=None, project_identifier=None):
def update_connector(self, identifier, data, org_identifier=None, project_identifier=None):